@@ -38,34 +38,17 @@ our @EXPORT_OK = qw(
 our $VERSION = $AnyEvent::VERSION;
 
 BEGIN {
-   my $af_inet6 = eval { local $SIG{__DIE__}; &Socket::AF_INET6 };
-
-   # uhoh
-   $af_inet6 ||= 10 if $^O =~ /linux/;
-   $af_inet6 ||= 23 if $^O =~ /cygwin/i;
-   $af_inet6 ||= 23 if AnyEvent::WIN32;
-   $af_inet6 ||= 24 if $^O =~ /openbsd|netbsd/;
-   $af_inet6 ||= 28 if $^O =~ /freebsd/;
-
-   $af_inet6 && socket my $ipv6_socket, $af_inet6, &Socket::SOCK_STREAM, 0 # check if they can be created
-      or $af_inet6 = 0;
-
-   eval "sub AF_INET6() { $af_inet6 }"; die if $@;
-
-   delete $AnyEvent::PROTOCOL{ipv6} unless $af_inet6;
-}
-
-BEGIN {
-   # broken windows perls use undocumented error codes...
-   if (AnyEvent::WIN32) {
-      eval "sub WSAEINVAL      () { 10022 }";
-      eval "sub WSAEWOULDBLOCK () { 10035 }";
-      eval "sub WSAEINPROGRESS () { 10036 }";
+   # provide us with AF_INET6, but only if allowed
+   if (
+      $AnyEvent::PROTOCOL{ipv6}
+      && _AF_INET6
+      && socket my $ipv6_socket, _AF_INET6, Socket::SOCK_DGRAM(), 0 # check if they can be created
+   ) {
+      *AF_INET6 = \&_AF_INET6;
    } else {
-      # these should never match any errno value
-      eval "sub WSAEINVAL      () { -1e99 }";
-      eval "sub WSAEWOULDBLOCK () { -1e99 }";
-      eval "sub WSAEINPROGRESS () { -1e99 }";
+      # disable ipv6
+      *AF_INET6 = sub () { 0 };
+      delete $AnyEvent::PROTOCOL{ipv6};
    }
 
    # fix buggy Errno on some non-POSIX platforms
@@ -117,7 +100,7 @@ BEGIN {
          # vista returns fantasy port numbers.
 
          for (1..10) {
-            socket my $l, &Socket::AF_INET, &Socket::SOCK_STREAM, 0
+            socket my $l, Socket::AF_INET(), Socket::SOCK_STREAM(), 0
                or next;
 
             bind $l, Socket::pack_sockaddr_in 0, "\x7f\x00\x00\x01"
@@ -129,7 +112,7 @@ BEGIN {
             listen $l, 1
                or next;
 
-            socket my $r, &Socket::AF_INET, &Socket::SOCK_STREAM, 0
+            socket my $r, Socket::AF_INET(), Socket::SOCK_STREAM(), 0
                or next;
 
             bind $r, Socket::pack_sockaddr_in 0, "\x7f\x00\x00\x01"
@@ -173,7 +156,7 @@ BEGIN {
       };
 
       *portable_socketpair = sub () {
-         socketpair my $fh1, my $fh2, &Socket::AF_UNIX, &Socket::SOCK_STREAM, &Socket::PF_UNSPEC
+         socketpair my $fh1, my $fh2, Socket::AF_UNIX(), Socket::SOCK_STREAM(), Socket::PF_UNSPEC()
             or return;
 
          ($fh1, $fh2)
@@ -369,17 +352,15 @@ broken (i.e. windows) platforms.
 
 =cut
 
-sub fh_nonblocking($$) {
-   my ($fh, $nb) = @_;
-
-   require Fcntl;
-
-   if (AnyEvent::WIN32) {
-      $nb = (! ! $nb) + 0;
-      ioctl $fh, 0x8004667e, \$nb; # FIONBIO
-   } else {
-      fcntl $fh, &Fcntl::F_SETFL, $nb ? &Fcntl::O_NONBLOCK : 0;
-   }
+BEGIN {
+   *fh_nonblocking = AnyEvent::WIN32
+      ? sub($$) {
+          ioctl $_[0], 0x8004667e, pack "L", $_[1]; # FIONBIO
+        }
+      : sub($$) {
+          fcntl $_[0], AnyEvent::F_SETFL, $_[1] ? AnyEvent::O_NONBLOCK : 0;
+        }
+   ;
 }
 
 =item $guard = guard { CODE }
@@ -532,12 +513,13 @@ Like "<", but redirects the specified file descriptor instead.
 
 =item on_prepare => $cb
 
-Specify a callback that is executed just before the comamnd is C<exec>'ed,
+Specify a callback that is executed just before the command is C<exec>'ed,
 in the child process. Be careful not to use any event handling or other
 services not available in the child.
 
 This can be useful to set up the environment in special ways, such as
-changing the priority of the command.
+changing the priority of the command or manipulating signal handlers (e.g.
+setting C<SIGINT> to C<IGNORE>).
 
 =item close_all => $boolean
 
@@ -613,6 +595,8 @@ sub run_cmd {
          } elsif (ref $ob) {
             my ($pr, $pw) = AnyEvent::Util::portable_pipe;
             $cv->begin;
+
+            fcntl $pr, AnyEvent::F_SETFD, AnyEvent::FD_CLOEXEC;
             my $w; $w = AE::io $pr, 0,
                "SCALAR" eq ref $ob
                   ? sub {
@@ -654,6 +638,7 @@ sub run_cmd {
                $data = $ob->();
             }
 
+            fcntl $pw, AnyEvent::F_SETFD, AnyEvent::FD_CLOEXEC;
             my $w; $w = AE::io $pw, 1, sub {
                my $len = syswrite $pw, $data;
 
@@ -756,7 +741,7 @@ Croaks when it cannot encode the string.
 
 =item AnyEvent::Util::punycode_decode $string
 
-Tries to punycode-decode the given C<$string> and return it's unicode
+Tries to punycode-decode the given C<$string> and return its unicode
 form. Again, uppercase letters are not casefoled, you have to do that
 yourself.
 
@@ -944,7 +929,7 @@ much as IDNs can be secure, and reasonably efficient when confronted with
 IDNs that are already valid DNS names.
 
 At the moment, this function simply calls C<idn_nameprep $idn, 1>,
-returning it's argument when that function fails.
+returning its argument when that function fails.
 
 =cut
 
